# hexdoc-latex

<a href="https://github.com/hexdoc-dev/hexdoc"><img src="https://img.shields.io/endpoint?url=https://hexxy.media/api/v0/badge/hexdoc" alt="hexdoc" style="max-width:100%;"></a>

[hexdoc](https://pypi.org/project/hexdoc) plugin to generate a LaTeX document for a Patchouli book.

Based on [Jinja templates](https://github.com/SamsTheNerd/HexDocGen/tree/4be2f31288482130019c8394715e0b64acf11aac/doc/src/hexdoc/_templates) written by [SamsTheNerd](https://github.com/SamsTheNerd).
